@@ -21,14 +21,12 @@
 
 /* The interfaces in this file are subject to change at any time. */
 
-#ident "$Id: vtepango.h,v 1.1 2003/03/05 22:31:08 nalin Exp $"
 
-#include "../config.h"
 #include "vtedraw.h"
 
 G_BEGIN_DECLS
 
-extern struct _vte_draw_impl _vte_draw_pango;
+extern const struct _vte_draw_impl _vte_draw_pango;
 
 G_END_DECLS
 
