@@ -208,13 +208,13 @@ _vte_pango_x_set_background_image(struct _vte_draw *draw,
 	if (data->pixmap != NULL) {
 		g_object_unref(data->pixmap);
 	}
-	draw->has_background_image = FALSE;
+	draw->requires_clear = FALSE;
 	data->pixmap = NULL;
 	data->pixmapw = data->pixmaph = 0;
 	if (pixmap != NULL) {
 		data->pixmap = pixmap;
 		gdk_drawable_get_size(pixmap, &data->pixmapw, &data->pixmaph);
-		draw->has_background_image =
+		draw->requires_clear =
 			data->pixmapw > 0 && data->pixmaph > 0;
 	}
 }
@@ -445,7 +445,7 @@ _vte_pango_x_draw_rectangle(struct _vte_draw *draw,
 	gdk_gc_set_foreground(data->gc, &wcolor);
 
 	gdk_draw_rectangle(draw->widget->window, data->gc, FALSE,
-			   x, y, width, height);
+			   x, y, width-1, height-1);
 }
 
 static void
@@ -475,7 +475,7 @@ _vte_pango_x_set_scroll(struct _vte_draw *draw, gint x, gint y)
 }
 
 const struct _vte_draw_impl _vte_draw_pango_x = {
-	"PangoX",
+	"pangox",
 	_vte_pango_x_check,
 	_vte_pango_x_create,
 	_vte_pango_x_destroy,
